#pragma once
#include "rawuievent.hpp"


#ifdef __INPUT_RAWCSAMEVENT_CPP_ 
#define RAW_CSAM_EVENT_DECL FDX_DLL_EXPORT 
#else 
#define RAW_CSAM_EVENT_DECL FDX_DLL_IMPORT 
#endif

namespace Input
{
   /**
   <summary>
   Common data for RawMouseEvent and RawKeyboardEvent
   </summary>
   */
   class RawCSAMEvent :
      public RawUIEvent
   {
   public:
      RAW_CSAM_EVENT_DECL RawCSAMEvent();
      RAW_CSAM_EVENT_DECL RawCSAMEvent(const parameter_strings & parms);

      RAW_CSAM_EVENT_DECL virtual ~RawCSAMEvent();

      DECL_CLASS_COMMON_TYPES(RawCSAMEvent);

      RAW_CSAM_EVENT_DECL void initialize(const parameter_strings & parms); 

      ///<summary>Give comparisons value semantics</summary>
      RAW_CSAM_EVENT_DECL bool operator==(RawCSAMEvent const& cmp) const;

   public:
      /**
      <summary>(from W3C DOM L3 Events) 
      true if the 'Control' (control) key modifier was active.

      The uninitialized value of this attribute must be false.
      </summary>
      */
      bool ctrlKey;

      /**
      <summary>(from W3C DOM L3 Events) 
      true if the 'Alt' (alternative) or Option key modifier was active.

      The uninitialized value of this attribute must be false.
      </summary>
      */
      bool altKey;

      /**
      <summary>
      true if the shift (Shift) key modifier was active.

      The uninitialized value of this attribute must be false.
      </summary>
      */
      bool shiftKey;
      /**
      <summary>(from W3C DOM L3 Events) 
      true if the meta (Meta) key modifier was active.

      Note: The 'Command' key modifier on Macintosh systems is represented using this key modifier.

      The uninitialized value of this attribute must be false
      </summary>
      */
      bool metaKey;

   protected:
      friend class boost::serialization::access;
      template<class Archive>
      RAW_CSAM_EVENT_DECL void serialize(Archive &ar, const unsigned int version);
      //{
      //   ar & boost::serialization::base_object<RawUIEvent>(*this);
      //   ar & ctrlKey;
      //   ar & altKey;
      //   ar & shiftKey;
      //   ar & metaKey;
      //}
         


   };

}
BOOST_CLASS_EXPORT_KEY(Input::RawCSAMEvent);